@@ -13,6 +13,7 @@ from functools import partial
 from tornado import ioloop
 from tornado import gen
 from tornado.web import HTTPError
+import psutil
 
 from litedfs.data.config import CONFIG
 
@@ -59,6 +60,7 @@ class Errors(object):
         "OperationFailed": {"name": "OperationFailed", "message": "operation failed"},
         "OperationRunning": {"name": "OperationRunning", "message": "operation running"},
         "BlockNotExists": {"name": "BlockNotExists", "message": "block not exists"},
+        "ChecksumFailed": {"name": "ChecksumFailed", "message": "checksum failed"},
         "ReplicateBlockFailed": {"name": "ReplicateBlockFailed", "message": "replicate block failed"},
     }
 
@@ -197,9 +199,12 @@ def delete_block(name, block):
     try:
         dir_path = os.path.join(CONFIG["data_path"], "files", name[:2], name[2:4])
         file_path = os.path.join(dir_path, "%s_%s.blk" % (name, block))
+        tmp_file_path = os.path.join(dir_path, "%s_%s.blk.tmp" % (name, block))
         check_file_path = os.path.join(dir_path, "%s_%s.chk" % (name, block))
         if os.path.exists(file_path):
             os.remove(file_path)
+        if os.path.exists(tmp_file_path):
+            os.remove(tmp_file_path)
         if os.path.exists(check_file_path):
             os.remove(check_file_path)
         files = os.listdir(dir_path)
@@ -260,3 +265,34 @@ def async_post(async_client, url, files, params):
         body_producer = producer
     )
     return response
+
+
+def size_pretty(size):
+    result = ""
+    try:
+        if size > 1024*1014*1024*1024:
+            result = "%.3f T"%(size/1024.0/1024.0/1024.0/1024.0)
+        elif size > 1024*1014*1024:
+            result = "%.3f G"%(size/1024.0/1024.0/1024.0)
+        elif size > 1024*1024:
+            result = "%.3f M"%(size/1024.0/1024.0)
+        elif size > 1024:
+            result = "%.3f K"%(size/1024.0)
+        else:
+            result = "%d B"%size
+    except Exception as e:
+        LOG.exception(e)
+        result = "0 B"
+    return result
+
+
+def disk_usage(dir_path = None):
+    if not dir_path:
+        dir_path = CONFIG["data_path"]
+    usage = psutil.disk_usage(dir_path)
+    return {
+        "total": usage.total,
+        "used": usage.used,
+        "free": usage.free,
+        "percent": usage.percent
+    }
